# pylint: skip-file
import os

from fastapi import Body
from fastapi import Header
from fastapi import Request
from fastapi import Path
from fastapi.responses import Response
import unimatrix.const
import uvicorn

from .application import Application
from .baserequesthandler import BaseRequestHandler
from .dependantrunner import DependantRunner
from .dependency import Dependency
from .injected import Injected
from .messagepublisher import _default as MessagePublisher
from .namedquery import NamedQuery
from .publicresource import PublicResource
from .resource import Resource
from .queryrunner import QueryRunner
from . import transaction
from . import utils


__all__ = [
    'run',
    'utils',
    'transaction',
    'Application',
    'BaseRequestHandler',
    'DependantRunner',
    'Dependency',
    'Injected',
    'MessagePublisher',
    'NamedQuery',
    'PublicResource',
    'Resource',
    'QueryRunner',
]


def run(*args, **kwargs):
    """Like :func:`uvicorn.run`, but with additional integrations with
    Unimatrix.
    """
    if unimatrix.const.LOCALHOST_SSL_KEY is not None\
    and os.path.exists(unimatrix.const.LOCALHOST_SSL_KEY):
        kwargs.setdefault('ssl_keyfile', unimatrix.const.LOCALHOST_SSL_KEY)
    if unimatrix.const.LOCALHOST_SSL_CRT is not None\
    and os.path.exists(unimatrix.const.LOCALHOST_SSL_CRT):
        kwargs.setdefault('ssl_certfile', unimatrix.const.LOCALHOST_SSL_CRT)

    return uvicorn.run(*args, **kwargs)
