"""Declares :class:`Injected`."""
import typing

import ioc

from .dependency import Dependency


class Injected(Dependency): # pragma: no cover
    """A :class:`cbra.Dependency` implementation that uses the :mod:`ioc`
    module to provide a dependency.
    """
    __module__: str = 'cbra'

    def __init__(self, name, invoke: bool = False, default: typing.Any = None):
        self.name = name
        self.invoke = invoke
        self.default = default
        self.args = tuple()
        self.kwargs = {}
        super().__init__(use_cache=True)

    async def resolve(self):
        if not ioc.is_satisfied(self.name) and self.default is not None:
            dependency = self.default
        else:
            dependency = ioc.require(self.name)
        if not hasattr(dependency, '__aenter__'):
            yield dependency if not self.invoke else dependency(*args, **kwargs)
            return
        if self.invoke:
            dependency = dependency(*self.args, **self.kwargs)
        async with dependency:
            yield dependency
