"""Declares :class:`NamedQueryMetaclass`."""
import typing

import pydantic


class NamedQueryMetaclass(type):
    reserved_attrs: set = {
        "build",
        "resolve",
        "run",
    }

    def __new__(cls, name, bases, attrs):
        new = super().__new__
        if attrs.get('__abstract__', False):
            return new(cls, name, bases, attrs)
        attrs['__abstract__'] = False
        hints = attrs.get('__annotations__') or {}
        fields = {}
        for k in dict.keys(hints):
            if str.startswith(k, '_'):
                continue
            if k in cls.reserved_attrs:
                raise ValueError(f"Attribute `{k}` is a reserved name.")
            if k in attrs:
                fields[k] = attrs.pop(k)
        attrs['model'] = type(name, cls.get_model_bases(cls, bases), {
            '__annotations__': hints,
            **fields
        })

        return new(cls, name, bases, attrs)

    def get_model_bases(cls, bases: typing.List[type]) -> typing.Tuple[type]:
        """Return the bases that are used to construct the query model."""
        parents = [
            b for b in bases
            if isinstance(b, NamedQueryMetaclass)
            and not b.__abstract__
        ]
        return (pydantic.BaseModel,) if not parents else (parents[0].model,)
