"""Declares :class:`OptionsHandler`."""
import typing

import fastapi
import fastapi.responses

from .requesthandler import RequestHandler


class OptionsHandler(RequestHandler):
    """Handles options requests to the given base path."""

    def __init__(self, allowed_methods: typing.List[str], *args, **kwargs):
        super().__init__(*args, **kwargs)
        allowed_methods.append('OPTIONS')
        self.allowed_methods = list(sorted(set(allowed_methods)))

    async def __call__(self,
        request: fastapi.Request,
        response: fastapi.responses.Response,
        principal: dict,
        *args, **kwargs
    ):
        return fastapi.responses.Response(
            headers={
                'Allow': str.join(', ', self.allowed_methods)
            }
        )
