# pylint: skip-file
import pytest


class TestResourceClassConfiguration:

    @pytest.mark.asyncio
    async def test_retrieve_is_exposed(self, client):
        response = await client.get('/example/1')
        assert response.status_code == 200

    @pytest.mark.asyncio
    async def test_retrieve_receives_path_parameter(self, client):
        response = await client.get('/example/1')
        assert response.status_code == 200
        dto = response.json()
        assert dto.get('object_id') == '1'

    @pytest.mark.asyncio
    async def test_detail_options_is_exposed(self, client):
        response = await client.options('/example/1')
        assert response.status_code == 200

    @pytest.mark.asyncio
    async def test_list_is_exposed(self, client):
        response = await client.get('/example')
        assert response.status_code == 200

    @pytest.mark.asyncio
    async def test_list_options_is_exposed(self, client):
        response = await client.options('/example')
        assert response.status_code == 200

    @pytest.mark.asyncio
    async def test_update_is_exposed(self, client):
        response = await client.patch('/example/1', json={})
        assert response.status_code == 200

    @pytest.mark.asyncio
    async def test_update_receives_path_parameter(self, client):
        response = await client.patch('/example/1', json={})
        assert response.status_code == 200
        dto = response.json()
        assert dto.get('object_id') == '1'

    @pytest.mark.asyncio
    async def test_update_receives_object(self, client):
        response = await client.patch('/example/1', json={'foo': 'bar'})
        assert response.status_code == 200
        dto = response.json()
        assert dto.get('object_id') == '1'
        assert dto.get('dto') == {'foo': 'bar'}

    @pytest.mark.asyncio
    async def test_replace_is_exposed(self, client):
        response = await client.put('/example/1', json={})
        assert response.status_code == 200

    @pytest.mark.asyncio
    async def test_replace_receives_path_parameter(self, client):
        response = await client.put('/example/1', json={})
        assert response.status_code == 200
        dto = response.json()
        assert dto.get('object_id') == '1'

    @pytest.mark.asyncio
    async def test_replace_receives_object(self, client):
        response = await client.put('/example/1', json={'foo': 'bar'})
        assert response.status_code == 200
        dto = response.json()
        assert dto.get('object_id') == '1'
        assert dto.get('dto') == {'foo': 'bar'}

    @pytest.mark.asyncio
    async def test_destroy_is_exposed(self, client):
        response = await client.delete('/example/1')
        assert response.status_code == 200

    @pytest.mark.asyncio
    async def test_destroy_receives_path_parameter(self, client):
        response = await client.delete('/example/1')
        assert response.status_code == 200
        dto = response.json()
        assert dto.get('object_id') == '1'

    @pytest.mark.asyncio
    async def test_create_is_exposed(self, client):
        response = await client.post('/example', json={})
        assert response.status_code == 200

    @pytest.mark.asyncio
    async def test_create_receives_object(self, client):
        response = await client.post('/example', json={'foo': 'bar'})
        assert response.status_code == 200
        dto = response.json()
        assert dto.get('dto') == {'foo': 'bar'}

    @pytest.mark.asyncio
    async def test_receive_is_exposed(self, client):
        response = await client.post('/example/1', json={})
        assert response.status_code == 200

    @pytest.mark.asyncio
    async def test_receive_receives_path_parameter(self, client):
        response = await client.post('/example/1', json={})
        assert response.status_code == 200
        dto = response.json()
        assert dto.get('object_id') == '1'

    @pytest.mark.asyncio
    async def test_receive_receives_object(self, client):
        response = await client.post('/example/1', json={'foo': 'bar'})
        assert response.status_code == 200
        dto = response.json()
        assert dto.get('object_id') == '1'
        assert dto.get('dto') == {'foo': 'bar'}
