# pylint: skip-file
import inspect
import typing

from .mediatypes import media_type_matches


__all__ = [
	'media_type_matches',
    'normalize_signature'
]


def normalize_signature(func):
    """Normalize the signature of a function or method so that it
    can be used as a :mod:`fastapi` request handler.
    """
    sig = inspect.signature(func)
    func.__signature__ = sig.replace(
        parameters=[
            x for x in sig.parameters.values()
            if x.name != 'self'
        ]
    )
    return func


class PositionalArgument(inspect.Parameter):

    def __init__(self,
        name: str,
        annotation: type = None,
        default: typing.Any = None
    ):
        super().__init__(
            name=name,
            kind=inspect.Parameter.POSITIONAL_ONLY,
            default=default,
            annotation=annotation
        )
