"""Demonstrates basic usage of class-based views with FastAPI."""
import fastapi

import cbra


class Subresource(cbra.PublicResource):
    path_parameter: int = 'child_id'
    name: str = 'sub'

    async def list(self, object_id: str):
        return {'object_id': object_id}

    async def retrieve(self, object_id: str, child_id: int):
        return {'object_id': object_id, 'child_id': child_id}


class ExampleResource(cbra.PublicResource):
    name: str = 'example'
    path_parameter: str = 'object_id'
    subresources = [Subresource]

    async def create(self, dto: dict):
        return dto

    async def list(self):
        return []

    async def destroy(self, object_id: str):
        return {'object_id': object_id}

    async def exists(self, object_id: str):
        return {'object_id': object_id}

    async def receive(self, object_id: str, dto: dict):
        return {'object_id': object_id, 'dto': dto}

    async def replace(self, object_id: str, dto: dict):
        return {'object_id': object_id, 'dto': dto}

    async def retrieve(self, object_id: str):
        return {'object_id': object_id}

    async def update(self, object_id: str, dto: dict):
        return {'object_id': object_id, 'dto': dto}


class ExampleProtectedResource(cbra.Resource):
    name: str = 'protected'
    path_parameter: str = 'object_id'

    async def retrieve(self, object_id: str):
        return {'object_id': object_id, 'principal': self.principal}


app = fastapi.FastAPI(
    docs_url='/ui',
    redoc_url='/docs'
)
ExampleResource.add_to_router(app)
ExampleProtectedResource.add_to_router(app)


if __name__ == '__main__':
    cbra.run('__main__:app', port=5000, reload=True)
